@@ -322,6 +322,13 @@ void fillSettingsFromUrl( const Url &url, media::TransferSettings &s )
     if( ! param.empty() && param == "no" )
       s.setHeadRequestsAllowed( false );
   }
+  {
+    const auto &cookieFileParam = url.getQueryParam( "cookies" );
+    if ( !cookieFileParam.empty() && str::strToBool( cookieFileParam, true ) )
+      s.setEnableCookieFile ( true );
+    else
+      s.setEnableCookieFile ( false );
+  }
 }
 
 /**
@@ -471,7 +478,7 @@ int CurlPollHelper::timercb(CURLM *, long timeout_ms, CurlPollHelper *thatPtr) {
 
 CURLMcode internal::CurlPollHelper::handleSocketActions( const std::vector<GPollFD> &actionsFds , int first )
 {
-  for ( int sock = first; sock < actionsFds.size(); sock++ ) {
+  for ( size_t sock = first; sock < actionsFds.size(); sock++ ) {
     const auto &waitFd = actionsFds[sock];
     if ( waitFd.revents == 0 )
       continue;
